@@ -1,13 +1,13 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package Log::Report::Translator::Context;
 use vars '$VERSION';
-$VERSION = '1.04';
+$VERSION = '1.06';
 
 
 use Log::Report 'log-report-lexicon';
@@ -26,10 +26,10 @@ sub rules() {shift->{LRTC_rules}}
 
 #-------
 
-sub _strip_tags($)
+sub _strip_ctxt_spec($)
 {   my $msgid = shift;
     my @tags;
-    while($msgid =~ s/\{ ([^}]*) \<(\w+) ([^}]*) \}/
+    while($msgid =~ s/\{ ([^<}]*) \<(\w+) ([^}]*) \}/
                       length "$1$3" ? "{$1$3}" : ''/xe)
     {  push @tags, $2;
     }
@@ -39,7 +39,7 @@ sub _strip_tags($)
 sub ctxtFor($$;$)
 {   my ($self, $msg, $lang, $def_context) = @_;
     my $rawid = $msg->msgid;
-    my ($msgid, $tags) = _strip_tags $rawid;
+    my ($msgid, $tags) = _strip_ctxt_spec $rawid;
     @$tags or return ($msgid, undef);
 
     my $maps = $self->rules;
@@ -48,7 +48,7 @@ sub ctxtFor($$;$)
     my $msg_context = $self->needDecode($rawid, $msg->context || {});
     $def_context  ||= {};
 #use Data::Dumper;
-#warn "$context = ", Dumper $msg, $msg_context, $def_context;
+#warn "context = ", Dumper $msg, $msg_context, $def_context;
 
     my @c;
     foreach my $tag (@$tags)
@@ -98,7 +98,7 @@ sub needDecode($@)
 
 sub expand($$@)
 {   my ($self, $raw, $lang) = @_;
-    my ($msgid, $tags) = _strip_tags $raw;
+    my ($msgid, $tags) = _strip_ctxt_spec $raw;
 
     $lang =~ s/_.*//;
 
@@ -146,5 +146,6 @@ sub _context_table($)
     \%rules;
 }
 
+#------------
 
 1;
